==> ansys_dyna_core-0.6.1-py3-none-any.whl: ansys/dyna/core/keywords/keyword_classes/auto/ale_structured_mesh_refine.py <==
# Copyright (C) 2021 - 2024 ANSYS, Inc. and/or its affiliates.
# SPDX-License-Identifier: MIT
#
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import typing
from ansys.dyna.core.lib.card import Card, Field, Flag
from ansys.dyna.core.lib.keyword_base import KeywordBase

class AleStructuredMeshRefine(KeywordBase):
    """DYNA ALE_STRUCTURED_MESH_REFINE keyword"""

    keyword = "ALE"
    subkeyword = "STRUCTURED_MESH_REFINE"

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self._cards = [
            Card(
                [
                    Field(
                        "mshid",
                        int,
                        0,
                        10,
                        kwargs.get("mshid", 0)
                    ),
                    Field(
                        "ifx,",
                        int,
                        10,
                        10,
                        kwargs.get("ifx,", 1)
                    ),
                    Field(
                        "ify,",
                        int,
                        20,
                        10,
                        kwargs.get("ify,", 1)
                    ),
                    Field(
                        "ifz,",
                        int,
                        30,
                        10,
                        kwargs.get("ifz,", 1)
                    ),
                ],
            ),
        ]

    @property
    def mshid(self) -> int:
        """Get or set the S-ALE Mesh ID. The ID of the Structured ALE mesh to be refined.
        """ # nopep8
        return self._cards[0].get_value("mshid")

    @mshid.setter
    def mshid(self, value: int) -> None:
        self._cards[0].set_value("mshid", value)

    @property
    def ifx_(self) -> int:
        """Get or set the Refinement factor at each local direction. Please see remark 1.
        """ # nopep8
        return self._cards[0].get_value("ifx,")

    @ifx_.setter
    def ifx_(self, value: int) -> None:
        self._cards[0].set_value("ifx,", value)

    @property
    def ify_(self) -> int:
        """Get or set the Refinement factor at each local direction. Please see remark 1.
        """ # nopep8
        return self._cards[0].get_value("ify,")

    @ify_.setter
    def ify_(self, value: int) -> None:
        self._cards[0].set_value("ify,", value)

    @property
    def ifz_(self) -> int:
        """Get or set the Refinement factor at each local direction. Please see remark 1.
        """ # nopep8
        return self._cards[0].get_value("ifz,")

    @ifz_.setter
    def ifz_(self, value: int) -> None:
        self._cards[0].set_value("ifz,", value)

==> ansys_dyna_core-0.7.0-py3-none-any.whl: ansys/dyna/core/keywords/keyword_classes/auto/ale_structured_mesh_refine.py <==
# Copyright (C) 2021 - 2024 ANSYS, Inc. and/or its affiliates.
# SPDX-License-Identifier: MIT
#
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import typing
from ansys.dyna.core.lib.card import Card, Field, Flag
from ansys.dyna.core.lib.config import use_lspp_defaults
from ansys.dyna.core.lib.keyword_base import KeywordBase

class AleStructuredMeshRefine(KeywordBase):
    """DYNA ALE_STRUCTURED_MESH_REFINE keyword"""

    keyword = "ALE"
    subkeyword = "STRUCTURED_MESH_REFINE"

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self._cards = [
            Card(
                [
                    Field(
                        "mshid",
                        int,
                        0,
                        10,
                        kwargs.get("mshid", 0 if use_lspp_defaults() else None)
                    ),
                    Field(
                        "ifx,",
                        int,
                        10,
                        10,
                        kwargs.get("ifx,", 1 if use_lspp_defaults() else None)
                    ),
                    Field(
                        "ify,",
                        int,
                        20,
                        10,
                        kwargs.get("ify,", 1 if use_lspp_defaults() else None)
                    ),
                    Field(
                        "ifz,",
                        int,
                        30,
                        10,
                        kwargs.get("ifz,", 1 if use_lspp_defaults() else None)
                    ),
                ],
            ),
        ]

    @property
    def mshid(self) -> int:
        """Get or set the S-ALE Mesh ID. The ID of the Structured ALE mesh to be refined.
        """ # nopep8
        return self._cards[0].get_value("mshid")

    @mshid.setter
    def mshid(self, value: int) -> None:
        self._cards[0].set_value("mshid", value)

    @property
    def ifx_(self) -> int:
        """Get or set the Refinement factor at each local direction. Please see remark 1.
        """ # nopep8
        return self._cards[0].get_value("ifx,")

    @ifx_.setter
    def ifx_(self, value: int) -> None:
        self._cards[0].set_value("ifx,", value)

    @property
    def ify_(self) -> int:
        """Get or set the Refinement factor at each local direction. Please see remark 1.
        """ # nopep8
        return self._cards[0].get_value("ify,")

    @ify_.setter
    def ify_(self, value: int) -> None:
        self._cards[0].set_value("ify,", value)

    @property
    def ifz_(self) -> int:
        """Get or set the Refinement factor at each local direction. Please see remark 1.
        """ # nopep8
        return self._cards[0].get_value("ifz,")

    @ifz_.setter
    def ifz_(self, value: int) -> None:
        self._cards[0].set_value("ifz,", value)
